@@ -6,25 +6,29 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.05 23:00:00                  #
+# Updated Date: 2025.01.16 04:00:00                  #
 # ================================================== #
 
 import json
 import time
+from typing import Optional, Any, List, Dict
 
 from PySide6.QtCore import QObject, Signal, Slot, QRunnable
 
+from pygpt_net.core.events import KernelEvent, RenderEvent
+from pygpt_net.core.bridge.context import BridgeContext
 from pygpt_net.item.ctx import CtxItem
 from pygpt_net.utils import trans, get_image_extensions
 
 
-class Threads:
+class Threads(QObject):
     def __init__(self, window=None):
         """
         Assistant threads controller
 
         :param window: Window instance
         """
+        super(Threads, self).__init__()
         self.window = window
         self.started = False
         self.stop = False  # force stop run
@@ -43,7 +47,11 @@ class Threads:
         self.window.core.ctx.append_thread(thread_id)
         return thread_id
 
-    def handle_output_message(self, ctx: CtxItem, stream: bool = False):
+    def handle_output_message(
+            self,
+            ctx: CtxItem,
+            stream: bool = False
+    ):
         """
         Handle output message (not stream ONLY)
 
@@ -56,7 +64,12 @@ class Threads:
         self.window.controller.chat.output.handle(ctx, 'assistant', stream)
 
         if stream:  # append all output to chat
-            self.window.controller.chat.render.end(ctx.meta, ctx, stream=stream)  # extra reload for stream markdown needed here
+            event = RenderEvent(RenderEvent.END, {
+                "meta": ctx.meta,
+                "ctx": ctx,
+                "stream": stream,
+            })  # extra reload for stream markdown needed here
+            self.window.dispatch(event)
 
         ctx.clear_reply()  # reset results
 
@@ -78,13 +91,18 @@ class Threads:
         self.window.controller.ctx.update()
 
         # if is command execute and not locked yet (not executing)
-        if has_cmd and self.window.controller.chat.reply.waiting():
+        if has_cmd and self.window.controller.kernel.stack.waiting():
             self.log("Replying for message command...")
-            self.window.controller.chat.reply.handle()
+            self.window.controller.kernel.stack.handle()
 
         self.log("Handled output message.")
 
-    def handle_message_data(self, ctx: CtxItem, msg, stream: bool = False):
+    def handle_message_data(
+            self,
+            ctx: CtxItem,
+            msg,
+            stream: bool = False
+    ):
         """
         Handle message data (files, images, text) - stream and not-stream
 
@@ -210,8 +228,10 @@ class Threads:
         ctx.tool_calls = self.window.core.command.unpack_tool_calls(
             run.required_action.submit_tool_outputs.tool_calls
         )
-        self.window.statusChanged.emit(trans('assistant.run.func.call'))
-        self.window.stateChanged.emit(self.window.STATE_IDLE)
+        event = KernelEvent(KernelEvent.STATE_IDLE, {
+            'msg': trans('assistant.run.func.call'),
+        })
+        self.window.dispatch(event)
         self.handle_tool_calls(ctx)
 
     def handle_tool_calls(self, ctx: CtxItem):
@@ -247,9 +267,9 @@ class Threads:
         # index ctx (llama-index)
         self.window.controller.idx.on_ctx_end(ctx, mode="assistant")
 
-        if has_calls and self.window.controller.chat.reply.waiting():
+        if has_calls and self.window.controller.kernel.stack.waiting():
             self.log("Replying for tool call...")
-            self.window.controller.chat.reply.handle()
+            self.window.controller.kernel.stack.handle()
             return
 
         # check if there are any response, if not send empty response
@@ -262,15 +282,24 @@ class Threads:
             results = {
                 "response": "",
             }
-            self.window.controller.chat.input.send(
-                text=json.dumps(results),
-                force=True,
-                reply=True,
-                internal=True,
-                prev_ctx=ctx,
-            )
+            context = BridgeContext()
+            context.ctx = ctx
+            context.prompt = json.dumps(results)
+            extra = {
+                "force": True,
+                "reply": True,
+                "internal": True,
+            }
+            event = KernelEvent(KernelEvent.INPUT_SYSTEM, {
+                'context': context,
+                'extra': extra,
+            })
+            self.window.dispatch(event)
 
-    def handle_tool_outputs(self, ctx: CtxItem) -> list:
+    def handle_tool_outputs(
+            self,
+            ctx: CtxItem
+    ) -> List[Dict[str, Any]]:
         """
         Handle tool outputs
 
@@ -288,7 +317,10 @@ class Threads:
         return tools_outputs
 
 
-    def apply_outputs(self, ctx: CtxItem) -> list:
+    def apply_outputs(
+            self,
+            ctx: CtxItem
+    ) -> List[Dict[str, Any]]:
         """
         Apply tool call outputs
 
@@ -300,7 +332,12 @@ class Threads:
         ctx.tool_calls = self.tool_calls  # set previous tool calls
         return self.window.core.command.get_tool_calls_outputs(ctx)
 
-    def handle_run_created(self, ctx: CtxItem, run, stream: bool = False):
+    def handle_run_created(
+            self,
+            ctx: CtxItem,
+            run,
+            stream: bool = False
+    ):
         """
         Handle run created (stream and not stream)
 
@@ -314,7 +351,7 @@ class Threads:
         self.window.core.ctx.append_run(ctx.run_id)  # get run ID and store in ctx
         self.handle_run(ctx, run, stream)  # handle assistant run
 
-    def handle_run_error(self, ctx: CtxItem, err):
+    def handle_run_error(self, ctx: CtxItem, err: Any):
         """
         Handle run created (stream and not stream)
 
@@ -324,16 +361,26 @@ class Threads:
         stream = self.window.core.config.get('stream')
         ctx.current = False  # reset current state
         ctx.from_previous()
-        self.window.controller.chat.render.end(ctx.meta, ctx, stream=stream)  # extra reload for stream markdown needed here
+        event = RenderEvent(RenderEvent.END, {
+            "meta": ctx.meta,
+            "ctx": ctx,
+            "stream": stream,
+        })  # extra reload for stream markdown needed here
+        self.window.dispatch(event)
         self.window.core.ctx.update_item(ctx)
         self.window.controller.ctx.update()
         self.window.core.debug.log(err)
         self.window.ui.dialogs.alert(err)
-        self.window.ui.status("An error occurred. Please try again.")
+        self.window.update_status("An error occurred. Please try again.")
         self.window.controller.chat.common.unlock_input()  # unlock input
         # self.handle_stream_end(ctx)
 
-    def handle_run(self, ctx: CtxItem, run, stream: bool = False):
+    def handle_run(
+            self,
+            ctx: CtxItem,
+            run,
+            stream: bool = False
+    ):
         """
         Handle assistant's run (not stream ONLY)
 
@@ -389,10 +436,17 @@ class Threads:
 
         :param ctx: CtxItem
         """
-        self.window.stateChanged.emit(self.window.STATE_IDLE)
         self.window.controller.chat.common.unlock_input()  # unlock input
         self.stop = False
-        self.window.statusChanged.emit(trans('assistant.run.completed'))
+        event = KernelEvent(KernelEvent.STATE_IDLE, {
+            'msg': trans('assistant.run.completed'),
+        })
+        self.window.dispatch(event)
+        event = RenderEvent(RenderEvent.RELOAD, {
+            "meta": ctx.meta,
+            "ctx": ctx,
+        })
+        self.window.dispatch(event)
         self.window.controller.chat.common.show_response_tokens(ctx)  # update tokens
 
     def handle_status_error(self, ctx: CtxItem):
@@ -403,8 +457,10 @@ class Threads:
         """
         self.stop = False
         self.window.controller.chat.common.unlock_input()
-        self.window.statusChanged.emit(trans('assistant.run.failed'))
-        self.window.stateChanged.emit(self.window.STATE_ERROR)
+        event = KernelEvent(KernelEvent.STATE_ERROR, {
+            'msg': trans('assistant.run.failed'),
+        })
+        self.window.dispatch(event)
 
     def handle_run_step_created(self, ctx: CtxItem, stream: bool = False):
         """
@@ -437,8 +493,10 @@ class Threads:
         if status == "completed":
             self.stop = False
             self.handle_messages(ctx)
-            self.window.statusChanged.emit(trans('assistant.run.completed'))
-            self.window.stateChanged.emit(self.window.STATE_IDLE)
+            event = KernelEvent(KernelEvent.STATE_IDLE, {
+                'msg': trans('assistant.run.completed'),
+            })
+            self.window.dispatch(event)
             self.window.controller.chat.common.show_response_tokens(ctx)  # update tokens
 
         # function call
@@ -447,8 +505,10 @@ class Threads:
             ctx.tool_calls = self.window.core.command.unpack_tool_calls(
                 run.required_action.submit_tool_outputs.tool_calls
             )
-            self.window.statusChanged.emit(trans('assistant.run.func.call'))
-            self.window.stateChanged.emit(self.window.STATE_IDLE)
+            event = KernelEvent(KernelEvent.STATE_IDLE, {
+                'msg': trans('assistant.run.func.call'),
+            })
+            self.window.dispatch(event)
             self.handle_tool_calls(ctx)
 
         # error
@@ -465,7 +525,10 @@ class Threads:
     def handle_started(self):
         """Handle listening started"""
         self.log("Run: assistant is listening status...")
-        self.window.statusChanged.emit(trans('assistant.run.listening'))
+        event = KernelEvent(KernelEvent.STATUS, {
+            'status': trans('assistant.run.listening'),
+        })
+        self.window.dispatch(event)
 
     def is_log(self) -> bool:
         """
