@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.17 02:00:00                  #
+# Updated Date: 2025.06.28 16:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
@@ -22,6 +22,7 @@ from pygpt_net.core.types import (
     MODE_LANGCHAIN,
     MODE_LLAMA_INDEX,
     MODE_VISION,
+    MODE_RESEARCH,
 )
 from pygpt_net.utils import trans
 
@@ -55,12 +56,13 @@ class Custom:
         self.window.ui.config['preset'][MODE_COMPLETION].box.setText(trans("preset.completion"))
         self.window.ui.config['preset'][MODE_IMAGE].box.setText(trans("preset.img"))
         self.window.ui.config['preset'][MODE_VISION].box.setText(trans("preset.vision"))
-        self.window.ui.config['preset'][MODE_LANGCHAIN].box.setText(trans("preset.langchain"))
+        #self.window.ui.config['preset'][MODE_LANGCHAIN].box.setText(trans("preset.langchain"))
         self.window.ui.config['preset'][MODE_LLAMA_INDEX].box.setText(trans("preset.llama_index"))
         self.window.ui.config['preset'][MODE_AGENT].box.setText(trans("preset.agent"))
         self.window.ui.config['preset'][MODE_AGENT_LLAMA].box.setText(trans("preset.agent_llama"))
         self.window.ui.config['preset'][MODE_EXPERT].box.setText(trans("preset.expert"))
         self.window.ui.config['preset'][MODE_AUDIO].box.setText(trans("preset.audio"))
+        self.window.ui.config['preset'][MODE_RESEARCH].box.setText(trans("preset.research"))
 
         self.window.ui.config['global']['img_raw'].setText(trans("img.raw"))
 
