@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 19:00:00                  #
+# Updated Date: 2025.07.01 01:00:00                  #
 # ================================================== #
 
 from pygpt_net.core.types import (
@@ -228,15 +228,6 @@ class Mode:
         :param mode: current mode
         :return: True if attachments are allowed
         """
-        if mode in [MODE_VISION, MODE_ASSISTANT]:
-            return True
-
-        if mode in [MODE_IMAGE]:
-            return False
-
-        if self.window.controller.ui.vision.has_vision():
-            return True
-
         # event: UI: attachments
         # value = False
         event = Event(Event.UI_ATTACHMENTS, {
