@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.17 13:00:00                  #
+# Updated Date: 2025.02.01 16:00:00                  #
 # ================================================== #
 
 from typing import Any, Optional
@@ -176,6 +176,9 @@ class Tabs:
         elif tab.type == Tab.TAB_TOOL_PAINTER:
             if self.window.core.config.get('vision.capture.enabled'):
                 self.window.controller.camera.enable_capture()
+        elif tab.type == Tab.TAB_TOOL_CALENDAR:
+            self.window.controller.calendar.update()
+            self.window.controller.calendar.update_ctx_counters()
 
         if prev_tab != idx or prev_column != column_idx:
             self.window.dispatch(AppEvent(AppEvent.TAB_SELECTED))  # app event
@@ -280,7 +283,8 @@ class Tabs:
             return
         current_ctx = self.window.core.ctx.get_current()
         if (current_ctx is not None and current_ctx != tab.data_id) or current_ctx is None:
-            self.window.controller.ctx.select_on_list_only(tab.data_id)
+            if tab.type == Tab.TAB_CHAT:
+                self.window.controller.ctx.select_on_list_only(tab.data_id)
         self.window.controller.ui.update()
         self.update_current()
 
@@ -307,6 +311,8 @@ class Tabs:
 
         :param idx: column index
         """
+        if self.column_idx == idx:
+            return
         self.column_idx = idx
         self.on_column_changed()
         self.on_changed()
