@@ -6,15 +6,17 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.31 19:00:00                  #
+# Updated Date: 2025.07.01 01:00:00                  #
 # ================================================== #
 
 import json
 from typing import Optional, Dict, Any, List
 
+from llama_index.core.agent import AgentRunner
 from llama_index.core.llms import ChatMessage, MessageRole
 from llama_index.core.prompts import ChatPromptTemplate
 from llama_index.core.memory import ChatMemoryBuffer
+from llama_index.core.tools import QueryEngineTool
 
 from pygpt_net.core.types import (
     MODE_CHAT,
@@ -25,6 +27,7 @@ from pygpt_net.item.model import ModelItem
 from pygpt_net.item.ctx import CtxItem
 
 from .context import Context
+from .response import Response
 
 
 class Chat:
@@ -37,11 +40,8 @@ class Chat:
         self.window = window
         self.storage = storage
         self.context = Context(window)
-        self.tool_calls_not_allowed_providers = [
-            "ollama",
-            "hugging_face_api",
-            "deepseek_api",
-        ]
+        self.response = Response(window)
+        self.prev_message = None  # previous message, used in chat mode
 
     def call(
             self,
@@ -72,17 +72,11 @@ class Chat:
                 extra=extra,
             )
 
-        # if not raw, check if chat mode is available
-        if MODE_CHAT in model.llama_index['mode']:
-            return self.chat(
-                context=context,
-                extra=extra,
-            )
-        else:
-            return self.query(
-                context=context,
-                extra=extra,
-            )  # if not, use query mode
+        # chat
+        return self.chat(
+            context=context,
+            extra=extra,
+        )
 
     def raw_query(
             self,
@@ -131,7 +125,7 @@ class Chat:
             model.id,
         ))
 
-        index, llm = self.get_index(idx, model)
+        index, llm = self.get_index(idx, model, stream=stream)
         input_tokens = self.window.core.tokens.from_llama_messages(
             query,
             [],
@@ -186,6 +180,7 @@ class Chat:
         """
         idx = context.idx
         model = context.model
+        stream = context.stream
         ctx = context.ctx
         query = ctx.input  # user input
         verbose = self.window.core.config.get("log.llama", False)
@@ -196,7 +191,7 @@ class Chat:
             query,
         ))
 
-        index, llm = self.get_index(idx, model)
+        index, llm = self.get_index(idx, model, stream=stream)
         retriever = index.as_retriever()
         nodes = retriever.retrieve(query)
         outputs = []
@@ -219,13 +214,15 @@ class Chat:
     def chat(
             self,
             context: BridgeContext,
-            extra: Optional[Dict[str, Any]] = None
+            extra: Optional[Dict[str, Any]] = None,
+            disable_cmd: bool = False,
     ) -> bool:
         """
         Chat mode (conversation, using context from index) and append result to the context
 
         :param context: Bridge context
         :param extra: Extra arguments
+        :param disable_cmd: Disable tools
         """
         idx = context.idx
         model = context.model
@@ -237,9 +234,13 @@ class Chat:
         use_index = True
         verbose = self.window.core.config.get("log.llama", False)
         allow_native_tool_calls = True
-        if ('provider' in model.llama_index
-                and model.llama_index['provider'] in self.tool_calls_not_allowed_providers):
+        response = None
+        cmd_enabled = self.window.core.config.get("cmd", False)  # use tools
+        use_react = self.window.core.config.get("llama.idx.react", False)  # use ReAct agent for tool calls
+        if not self.window.core.models.is_tool_call_allowed(context.mode, model):
             allow_native_tool_calls = False
+        if disable_cmd:
+            cmd_enabled = False
 
         if idx is None or idx == "_":
             chat_mode = "simple"  # do not use query engine if no index
@@ -249,19 +250,32 @@ class Chat:
             raise Exception("Model config not provided")
 
         self.log("Chat with index...")
-        self.log("Idx: {}, query: {}, chat_mode: {}, model: {}".format(
-            idx,
-            query,
-            chat_mode,
-            model.id,
+        self.log("Idx: {idx}, "
+                 "chat_mode: {mode}, "
+                 "model: {model}, "
+                 "stream: {stream}, "
+                 "native tool calls: {tool_calls}, "
+                 "use react: {react}, "
+                 "use index: {use_index}, "
+                 "cmd enabled: {cmd_enabled}, "
+                 "query: {query}".format(
+            idx=idx,
+            mode=chat_mode,
+            model=model.id,
+            stream=stream,
+            tool_calls=allow_native_tool_calls,
+            react=use_react,
+            use_index=use_index,
+            cmd_enabled=cmd_enabled,
+            query=query,
         ))
 
         # use index only if idx is not empty, otherwise use only LLM
         index = None
         if use_index:
-            index, llm = self.get_index(idx, model)
+            index, llm = self.get_index(idx, model, stream=stream)
         else:
-            llm = self.window.core.idx.llm.get(model)
+            llm = self.window.core.idx.llm.get(model, stream=stream)
 
         # TODO: if multimodal support, try to get multimodal provider
         # if model.is_multimodal():
@@ -269,55 +283,130 @@ class Chat:
 
         # append context from DB
         history = self.context.get_messages(
-            ctx.input,
-            system_prompt,
-            context.history,
+            input_prompt=ctx.input,
+            system_prompt=system_prompt,
+            history=context.history,
+            allow_native_tool_calls=allow_native_tool_calls,
+            prev_message=self.prev_message,
+            attachments=context.attachments,
         )
+
+        self.prev_message = None  # reset previous message
         memory = self.get_memory_buffer(history, llm)
         input_tokens = self.window.core.tokens.from_llama_messages(
             query,
             history,
             model.id,
         )
+        ctx.input_tokens = input_tokens
+        tools = self.window.core.agents.tools.prepare(context, extra)
 
         if use_index:
-            # TOOLS: commands are applied to system prompt here
-            # index as query engine
-            chat_engine = index.as_chat_engine(
-                llm=llm,
-                chat_mode=chat_mode,
-                memory=memory,
-                verbose=verbose,
-                system_prompt=system_prompt,
-            )
-            if stream:
-                response = chat_engine.stream_chat(query)
-            else:
-                response = chat_engine.chat(query)
-        else:
-            # TOOLS: commands are applied to system prompt here
-            # prepare tools (native calls if enabled)
-            tools = self.window.core.agents.tools.prepare(context, extra)
-
-            # without index, use LLM as chat engine
-            history.insert(0, self.context.add_system(system_prompt))
-            history.append(self.context.add_user(query))
-            if stream:
-                # IMPORTANT: stream chat with tools not supported by all providers
-                if allow_native_tool_calls and hasattr(llm, "stream_chat_with_tools"):
-                    response = llm.stream_chat_with_tools(
-                        tools=tools,
-                        messages=history,
+            # 1) if tools enabled use agent engine
+            if cmd_enabled:
+                if use_react: # TOOLS + REACT + INDEX
+                    ctx.agent_call = True
+                    query_engine = index.as_query_engine(
+                        llm=llm,
+                        chat_mode=chat_mode,
+                        verbose=verbose,
                     )
+                    index_tool = QueryEngineTool.from_defaults(
+                        query_engine=query_engine,
+                        name="get_context",
+                        description="Get additional context to answer the question.",
+                        return_direct=True,  # return direct response from index
+                    )
+                    tools.append(index_tool)
+                    agent = AgentRunner.from_llm(
+                        tools=tools,
+                        llm=llm,
+                        memory=memory,
+                        verbose=True,
+                        system_prompt=system_prompt,
+                    )
+                    response = agent.chat(query)
                 else:
-                    response = llm.stream_chat(
-                        messages=history,
+                    chat_engine = index.as_chat_engine(
+                        llm=llm,
+                        chat_mode=chat_mode,
+                        memory=memory,
+                        verbose=verbose,
+                        system_prompt=system_prompt,
                     )
+                    if stream:
+                        response = chat_engine.stream_chat(query) # TOOLS + INDEX + STREAM
+                    else:
+                        response = chat_engine.chat(query) # TOOLS + INDEX
+
+                    # check for not empty
+                    if hasattr(response, "source_nodes") and len(response.source_nodes) == 0:
+                        self.log("No source nodes found in response, fallback to LLM directly...")
+                        use_index = False # fallback
             else:
-                # IMPORTANT: stream chat with tools not supported by all providers
-                if allow_native_tool_calls and hasattr(llm, "chat_with_tools"):
-                    response = llm.chat_with_tools(
+                # 2) if tools disabled, use index as chat engine
+                chat_engine = index.as_chat_engine(
+                    llm=llm,
+                    chat_mode=chat_mode,
+                    memory=memory,
+                    verbose=verbose,
+                    system_prompt=system_prompt,
+                )
+                if stream:
+                    response = chat_engine.stream_chat(query)
+                else:
+                    response = chat_engine.chat(query)
+
+                # check for not empty
+                if hasattr(response, "source_nodes") and len(response.source_nodes) == 0:
+                    self.log("No source nodes found in response, fallback to LLM directly...")
+                    use_index = False # fallback
+
+        if not use_index:
+            if cmd_enabled:
+                if use_react:  # TOOLS + REACT + NO INDEX
+                    ctx.agent_call = True
+                    agent = AgentRunner.from_llm(
                         tools=tools,
+                        llm=llm,
+                        memory=memory,
+                        verbose=True,
+                        system_prompt=system_prompt,
+                    )
+                    response = agent.chat(query)
+                else:
+                    history.insert(0, self.context.add_system(system_prompt))
+                    history.append(self.context.add_user(query, attachments=context.attachments))
+                    if stream: # TOOLS + STREAM + NO INDEX
+                        # IMPORTANT: stream chat with tools not supported by all providers
+                        if allow_native_tool_calls and hasattr(llm, "stream_chat_with_tools"):
+                            self.log("Using with tools...")
+                            response = llm.stream_chat_with_tools(
+                                tools=tools,
+                                messages=history,
+                            )
+                        else:
+                            response = llm.stream_chat(
+                                messages=history,
+                            )
+                    else: # TOOLS + NO INDEX
+                        # IMPORTANT: stream chat with tools not supported by all providers
+                        if allow_native_tool_calls and hasattr(llm, "chat_with_tools"):
+                            self.log("Using with tools...")
+                            response = llm.chat_with_tools(
+                                tools=tools,
+                                messages=history,
+                            )
+                        else:
+                            response = llm.chat(
+                                messages=history,
+                            )
+            else:
+                # NO TOOLS + NO INDEX
+                history.insert(0, self.context.add_system(system_prompt))
+                history.append(self.context.add_user(query, attachments=context.attachments))
+                if stream:
+                    response = llm.stream_chat(
                         messages=history,
                     )
                 else:
@@ -327,52 +416,65 @@ class Chat:
 
         # handle response
         if response:
-            if use_index:
-                # from index as query engine
-                if stream:
-                    ctx.stream = response.response_gen
-                    ctx.input_tokens = input_tokens
-                    ctx.set_output("", "")
-                    ctx.add_doc_meta(self.get_metadata(response.source_nodes))  # store metadata
+            # tools
+            if cmd_enabled:
+                if use_react:
+                    self.response.from_react(ctx, model, response) # TOOLS + REACT, non-stream
                 else:
-                    ctx.input_tokens = input_tokens
-                    ctx.output_tokens = self.window.core.tokens.from_llama_messages(
-                        response.response,
-                        [],
-                        model.id,
-                    )  # calc from response
-                    output = response.response
-                    if output is None:
-                        output = ""
-                    ctx.set_output(output, "")
-                    ctx.add_doc_meta(self.get_metadata(response.source_nodes))  # store metadata
+                    if stream:
+                        if use_index:
+                            self.response.from_index_stream(ctx, model, response) # INDEX + STREAM
+                        else:
+                            self.response.from_llm_stream(ctx, model, llm, response)  # LLM + STREAM
+                    else:
+                        if use_index:
+                            self.response.from_index(ctx, model, response) # TOOLS + INDEX
+                        else:
+                            self.response.from_llm(ctx, model, llm, response) # TOOLS + LLM
             else:
-                # from LLM directly, no index
+                # no tools
                 if stream:
-                    # tools are handled in stream output controller
-                    ctx.stream = response  # chunk is in response.delta
-                    ctx.input_tokens = input_tokens
-                    ctx.set_output("", "")
+                    if use_index:
+                        self.response.from_index_stream(ctx, model, response) # INDEX + STREAM
+                    else:
+                        self.response.from_llm_stream(ctx, model, llm, response) # LLM + STREAM
                 else:
-                    # unpack tool calls
-                    tool_calls = llm.get_tool_calls_from_response(
-                        response,
-                        error_on_no_tool_call=False,
-                    )
-                    ctx.tool_calls = self.window.core.command.unpack_tool_calls_from_llama(tool_calls)
-                    output = response.message.content
-                    if output is None:
-                        output = ""
-                    ctx.set_output(output, "")
-                    ctx.input_tokens = input_tokens
-                    ctx.output_tokens = self.window.core.tokens.from_llama_messages(
-                        output,
-                        [],
-                        model.id,
-                    ) # calc from response
+                    if use_index:
+                        self.response.from_index(ctx, model, response) # INDEX
+                    else:
+                        self.response.from_llm(ctx, model, llm, response) # LLM
+
+            if not stream:
+                # store output tokens
+                ctx.output_tokens = self.window.core.tokens.from_llama_messages(
+                    response.response,
+                    [],
+                    model.id,
+                )
+                # store prev message
+                if (cmd_enabled and not use_react and not use_index) or (not cmd_enabled and not use_index):
+                    self.prev_message = response.message
+
+            # store metadata from response
+            if hasattr(response, "source_nodes") and response.source_nodes:
+                ctx.add_doc_meta(self.get_metadata(response.source_nodes))  # store metadata
             return True
+
         return False
 
+    def is_stream_allowed(self) -> bool:
+        """
+        Return if stream mode allowed
+
+        :return: True if stream allowed
+        """
+        use_react = self.window.core.config.get("llama.idx.react", False)  # use ReAct agent for tool calls
+        is_cmd = self.window.core.config.get("cmd", False)
+        if is_cmd:
+            if use_react:
+                return False
+        return True
+
     def query_file(
             self,
             ctx: CtxItem,
@@ -392,7 +494,7 @@ class Chat:
         if model is None:
             model = self.window.core.models.from_defaults()
 
-        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model)
+        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model, stream=False)
         tmp_id, index = self.storage.get_tmp(path, llm, embed_model)  # get or create tmp index
 
         idx = "tmp:{}".format(path)  # tmp index id
@@ -452,7 +554,7 @@ class Chat:
         id = json.dumps(parts)
         if model is None:
             model = self.window.core.models.from_defaults()
-        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model)
+        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model, stream=False)
         tmp_id, index = self.storage.get_tmp(id, llm, embed_model)  # get or create tmp index
 
         idx = "tmp:{}".format(id)  # tmp index id
@@ -506,7 +608,7 @@ class Chat:
         """
         if model is None:
             model = self.window.core.models.from_defaults()
-        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model)
+        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model, stream=False)
         index = self.storage.get_ctx_idx(path, llm, embed_model)
 
         # 1. try to retrieve directly from index
@@ -558,7 +660,7 @@ class Chat:
         """
         if model is None:
             model = self.window.core.models.from_defaults()
-        index, llm = self.get_index(idx, model)
+        index, llm = self.get_index(idx, model, stream=False)
         retriever = index.as_retriever()
         nodes = retriever.retrieve(query)
         response = ""
@@ -623,25 +725,27 @@ class Chat:
     def get_index(
             self,
             idx: str,
-            model: ModelItem
+            model: ModelItem,
+            stream: bool = False,
     ):
         """
         Get index instance
 
         :param idx: idx name (id)
         :param model: model instance
+        :param stream: stream mode
         :return:
         """
         # check if index exists
         if not self.storage.exists(idx):
             if idx is None:
                 # create empty in memory idx
-                llm, embed_model = self.window.core.idx.llm.get_service_context(model=model)
-                index = self.storage.index_from_empty()
+                llm, embed_model = self.window.core.idx.llm.get_service_context(model=model, stream=stream)
+                index = self.storage.index_from_empty(embed_model)
                 return index, llm
             # raise Exception("Index not prepared")
 
-        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model)
+        llm, embed_model = self.window.core.idx.llm.get_service_context(model=model, stream=stream)
         index = self.storage.get(idx, llm, embed_model)  # get index
         return index, llm
 
