@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.16 01:00:00                  #
+# Updated Date: 2025.06.30 20:00:00                  #
 # ================================================== #
 
 import os.path
@@ -31,7 +31,7 @@ class Llm:
         :param window: Window instance
         """
         self.window = window
-        self.default_model = "gpt-3.5-turbo"
+        self.default_model = "gpt-4o-mini"
         self.default_embed = "openai"
         self.initialized = False
 
@@ -44,51 +44,53 @@ class Llm:
     def get(
             self,
             model: Optional[ModelItem] = None,
-            multimodal: bool = False
+            multimodal: bool = False,
+            stream: bool = False
     ) -> Union[BaseLLM, MultiModalLLM]:
         """
         Get LLM provider
 
         :param model: Model item
         :param multimodal: Allow multi-modal flag (True to get multimodal provider if available)
+        :param stream: Stream mode (True to enable streaming)
         :return: Llama LLM instance
         """
         # TMP: deprecation warning fix
         # https://github.com/DataDog/dd-trace-py/issues/8212#issuecomment-1971063988
         if not self.initialized:
-            import warnings
-            from langchain._api import LangChainDeprecationWarning
-            warnings.simplefilter("ignore", category=LangChainDeprecationWarning)
+            # import warnings
+            # from langchain._api import LangChainDeprecationWarning
+            # warnings.simplefilter("ignore", category=LangChainDeprecationWarning)
             self.initialized = True
 
         llm = None
         if model is not None:
-            if 'provider' in model.llama_index:
-                provider = model.llama_index['provider']
-                if provider in self.window.core.llm.llms:
-                    # init env vars
-                    self.window.core.llm.llms[provider].init(
+            provider = model.get_provider()
+            if provider in self.window.core.llm.llms:
+                # init env vars
+                self.window.core.llm.llms[provider].init(
+                    window=self.window,
+                    model=model,
+                    mode=MODE_LLAMA_INDEX,
+                    sub_mode="",
+                )
+                # get llama LLM instance
+                if multimodal and model.is_multimodal():
+                    # at first, try to get multimodal provider
+                    llm = self.window.core.llm.llms[provider].llama_multimodal(
                         window=self.window,
                         model=model,
-                        mode=MODE_LLAMA_INDEX,
-                        sub_mode="",
                     )
-                    # get llama LLM instance
-                    if multimodal and model.is_multimodal():
-                        # at first, try to get multimodal provider
-                        llm = self.window.core.llm.llms[provider].llama_multimodal(
-                            window=self.window,
-                            model=model,
-                        )
-                        if llm is not None:
-                            print("Using multimodal.")
+                    if llm is not None:
+                        print("Using multimodal.")
 
-                    if llm is None:
-                        # if no multimodal, get default llama provider
-                        llm = self.window.core.llm.llms[provider].llama(
-                            window=self.window,
-                            model=model,
-                        )
+                if llm is None:
+                    # if no multimodal, get default llama provider
+                    llm = self.window.core.llm.llms[provider].llama(
+                        window=self.window,
+                        model=model,
+                        stream=stream,
+                    )
 
         # default model
         if llm is None:
@@ -123,14 +125,16 @@ class Llm:
 
     def get_service_context(
             self,
-            model: Optional[ModelItem] = None
+            model: Optional[ModelItem] = None,
+            stream: bool = False,
     ):
         """
         Get service context + embeddings provider
 
         :param model: Model item (for query)
+        :param stream: Stream mode (True to enable streaming)
         :return: Service context instance
         """
-        llm = self.get(model=model)
+        llm = self.get(model=model, stream=stream)
         embed_model = self.get_embeddings_provider()
         return llm, embed_model
