@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.16 01:00:00                  #
+# Updated Date: 2025.07.01 01:00:00                  #
 # ================================================== #
 
 import copy
@@ -75,10 +75,12 @@ class CtxItem:
         self.sub_call = False  # is sub call
         self.sub_reply = False  # sub call reply
         self.hidden = False  # hidden context
+        self.use_responses_api = False  # use responses API format
         self.pid = 0
         self.audio_id = None
         self.audio_output = None
         self.audio_expires_ts = 0
+        self.response = None  # response object
 
 
     @property
