@@ -6,12 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.08.29 04:00:00                  #
+# Updated Date: 2024.12.14 22:00:00                  #
 # ================================================== #
 
 from datetime import datetime
 import re
 import time
+from typing import Dict, Optional, Tuple, List
 
 from sqlalchemy import text
 
@@ -46,11 +47,11 @@ class Storage:
 
     def prepare_query(
             self,
-            search_string: str = None,
-            filters: dict = None,
+            search_string: Optional[str] = None,
+            filters: Optional[dict] = None,
             search_content: bool = False,
             append_date_ranges: bool = True,
-    ):
+    ) -> Tuple[str, str, dict]:
         """
         Prepare query for search_string and filters
 
@@ -67,6 +68,9 @@ class Storage:
         # only base by default
         where_clauses.append("(m.root_id IS NULL OR m.root_id = 0)")
 
+        # join group
+        join_clauses.append("LEFT JOIN ctx_group g ON m.group_id = g.id")
+
         # search_string
         if search_string:
             date_ranges = search_by_date_string(search_string)
@@ -105,15 +109,16 @@ class Storage:
                     continue
                 mode = filter.get('mode', '=')
                 value = filter.get('value', '')
+                key_name = 'm.' + key
                 if isinstance(value, int):
-                    where_clauses.append(f"{key} {mode} :{key}")
+                    where_clauses.append(f"{key_name} {mode} :{key}")
                     bind_params[key] = value
                 elif isinstance(value, str):
-                    where_clauses.append(f"{key} {mode} :{key}")
+                    where_clauses.append(f"{key_name} {mode} :{key}")
                     bind_params[key] = f"%{value}%"
                 elif isinstance(value, list):
                     values = "(" + ",".join([str(x) for x in value]) + ")"
-                    where_clauses.append(f"{key} {mode} {values}")
+                    where_clauses.append(f"{key_name} {mode} {values}")
 
         where_statement = " AND ".join(where_clauses) if where_clauses else "1"
         join_statement = " ".join(join_clauses) if join_clauses else ""
@@ -122,14 +127,14 @@ class Storage:
 
     def get_meta(
             self,
-            search_string: str = None,
-            order_by: str = None,
-            order_direction: str = None,
-            limit: int = None,
-            offset: int = None,
-            filters: dict = None,
+            search_string: Optional[str] = None,
+            order_by: Optional[str] = None,
+            order_direction: Optional[str] = None,
+            limit: Optional[int] = None,
+            offset: Optional[int] = None,
+            filters: Optional[dict] = None,
             search_content: bool = False,
-    ) -> dict:
+    ) -> Dict[int, CtxMeta]:
         """
         Return dict with CtxMeta objects, indexed by ID
 
@@ -153,8 +158,18 @@ class Storage:
             append_date_ranges=True,
         )
         stmt_text = f"""
-            SELECT m.* FROM ctx_meta m {join_statement} WHERE {where_statement}
-            ORDER BY m.updated_ts DESC {limit_suffix}
+            SELECT 
+                m.*,
+                g.name as group_name,
+                g.uuid as group_uuid,
+                g.additional_ctx_json as group_additional_ctx_json
+            FROM 
+                ctx_meta m 
+                {join_statement} 
+            WHERE 
+                {where_statement}
+            ORDER BY 
+                m.updated_ts DESC {limit_suffix}
         """
         stmt = text(stmt_text).bindparams(**bind_params)
 
@@ -169,14 +184,24 @@ class Storage:
 
         return items
 
-    def get_meta_indexed(self) -> dict:
+    def get_meta_indexed(self) -> Dict[int, CtxMeta]:
         """
         Return dict with indexed CtxMeta objects, indexed by ID
 
         :return: dict of CtxMeta
         """
         stmt_text = f"""
-            SELECT * FROM ctx_meta WHERE indexed_ts > 0
+            SELECT 
+                m.*, 
+                g.name as group_name,
+                g.uuid as group_uuid,
+                g.additional_ctx_json as group_additional_ctx_json 
+            FROM 
+                ctx_meta m 
+            LEFT JOIN 
+                ctx_group g ON m.group_id = g.id
+            WHERE 
+                indexed_ts > 0
         """
         stmt = text(stmt_text)
         items = {}
@@ -189,7 +214,32 @@ class Storage:
                 items[meta.id] = meta
         return items
 
-    def get_meta_by_root_id_and_preset_id(self, root_id: int, preset_id: str) -> dict:
+    def get_item_by_id(self, id: int) -> Optional[CtxItem]:
+        """
+        Return ctx item by ID
+
+        :return: CtxItem
+        """
+        stmt = text("""
+            SELECT * FROM ctx_item WHERE id = :id
+        """).bindparams(id=id)
+        db = self.window.core.db.get_db()
+        with db.connect() as conn:
+            result = conn.execute(stmt)
+            row = result.fetchone()
+            if row:
+                item = CtxItem()
+                unpack_item(item, row._asdict())
+                meta = self.get_meta_by_id(item.meta_id)  # append meta
+                item.meta = meta
+                return item
+        return None
+
+    def get_meta_by_root_id_and_preset_id(
+            self,
+            root_id: int,
+            preset_id: str
+    ) -> Dict[int, CtxMeta]:
         """
         Return dict with indexed CtxMeta objects, indexed by ID
 
@@ -212,7 +262,7 @@ class Storage:
                 items[meta.id] = meta
         return items
 
-    def get_meta_by_id(self, id: int) -> CtxMeta or None:
+    def get_meta_by_id(self, id: int) -> Optional[CtxMeta]:
         """
         Return ctx meta by ID
 
@@ -248,7 +298,7 @@ class Storage:
                 return int(row.id)
         return 0
 
-    def get_items(self, id: int) -> list:
+    def get_items(self, id: int) -> List[CtxItem]:
         """
         Return ctx items list by ctx meta ID
 
@@ -377,7 +427,8 @@ class Storage:
                 is_archived = :is_archived,
                 label = :label,
                 root_id = :root_id,
-                parent_id = :parent_id
+                parent_id = :parent_id,
+                additional_ctx_json = :additional_ctx_json
             WHERE id = :id
         """).bindparams(
             id=meta.id,
@@ -400,12 +451,36 @@ class Storage:
             label=int(meta.label),
             root_id=meta.root_id,
             parent_id=meta.parent_id,
+            additional_ctx_json=pack_item_value(meta.additional_ctx),
         )
         with db.begin() as conn:
             conn.execute(stmt)
-            return True
 
-    def update_meta_all(self, meta: CtxMeta, items: list) -> bool:
+        # update group
+        if meta.group:
+            stmt = text("""
+                UPDATE ctx_group
+                SET
+                    name = :name,
+                    additional_ctx_json = :additional_ctx_json,
+                    updated_ts = :updated_ts
+                WHERE id = :id
+            """).bindparams(
+                id=meta.group.id,
+                name=meta.group.name,
+                additional_ctx_json=pack_item_value(meta.group.additional_ctx),
+                updated_ts=int(time.time()),
+            )
+            with db.begin() as conn:
+                conn.execute(stmt)
+
+        return True
+
+    def update_meta_all(
+            self,
+            meta: CtxMeta,
+            items: List[CtxItem]
+    ) -> bool:
         """
         Update all, meta and items
 
@@ -616,7 +691,8 @@ class Storage:
                 label,
                 group_id,
                 root_id,
-                parent_id
+                parent_id,
+                additional_ctx_json
             )
             VALUES 
             (
@@ -642,7 +718,8 @@ class Storage:
                 :label,
                 :group_id,
                 :root_id,
-                :parent_id
+                :parent_id,
+                :additional_ctx_json
             )
         """).bindparams(
             uuid=meta.uuid,
@@ -668,6 +745,7 @@ class Storage:
             group_id=meta.group_id,
             root_id=meta.root_id,
             parent_id=meta.parent_id,
+            additional_ctx_json=pack_item_value(meta.additional_ctx),
         )
         with db.begin() as conn:
             result = conn.execute(stmt)
@@ -694,6 +772,8 @@ class Storage:
                 output_name,
                 input_ts,
                 output_ts,
+                hidden_input,
+                hidden_output,
                 mode,
                 model,
                 thread_id,
@@ -705,12 +785,15 @@ class Storage:
                 images_json,
                 files_json,
                 attachments_json,
+                additional_ctx_json,
                 extra,
                 input_tokens,
                 output_tokens,
                 total_tokens,
                 is_internal,
-                docs_json
+                docs_json,
+                audio_id,
+                audio_expires_ts
             )
             VALUES 
             (
@@ -722,6 +805,8 @@ class Storage:
                 :output_name,
                 :input_ts,
                 :output_ts,
+                :hidden_input,
+                :hidden_output,
                 :mode,
                 :model,
                 :thread_id,
@@ -733,12 +818,15 @@ class Storage:
                 :images_json,
                 :files_json,
                 :attachments_json,
+                :additional_ctx_json,
                 :extra,
                 :input_tokens,
                 :output_tokens,
                 :total_tokens,
                 :is_internal,
-                :docs_json
+                :docs_json,
+                :audio_id,
+                :audio_expires_ts
             )
         """).bindparams(
             meta_id=int(meta.id),
@@ -749,6 +837,8 @@ class Storage:
             output_name=item.output_name,
             input_ts=int(item.input_timestamp or 0),
             output_ts=int(item.output_timestamp or 0),
+            hidden_input=item.hidden_input,
+            hidden_output=item.hidden_output,
             mode=item.mode,
             model=item.model,
             thread_id=item.thread,
@@ -760,12 +850,15 @@ class Storage:
             images_json=pack_item_value(item.images),
             files_json=pack_item_value(item.files),
             attachments_json=pack_item_value(item.attachments),
+            additional_ctx_json=pack_item_value(item.additional_ctx),
             extra=pack_item_value(item.extra),
             input_tokens=int(item.input_tokens or 0),
             output_tokens=int(item.output_tokens or 0),
             total_tokens=int(item.total_tokens or 0),
             is_internal=int(item.internal),
             docs_json=pack_item_value(item.doc_ids),
+            audio_id=item.audio_id,
+            audio_expires_ts=int(item.audio_expires_ts or 0)
         )
         with db.begin() as conn:
             result = conn.execute(stmt)
@@ -789,6 +882,8 @@ class Storage:
                 output_name = :output_name,
                 input_ts = :input_ts,
                 output_ts = :output_ts,
+                hidden_input = :hidden_input,
+                hidden_output = :hidden_output,
                 mode = :mode,
                 model = :model,
                 thread_id = :thread_id,
@@ -800,12 +895,15 @@ class Storage:
                 images_json = :images_json,
                 files_json = :files_json,
                 attachments_json = :attachments_json,
+                additional_ctx_json = :additional_ctx_json,
                 extra = :extra,
                 input_tokens = :input_tokens,
                 output_tokens = :output_tokens,
                 total_tokens = :total_tokens,
                 is_internal = :is_internal,
-                docs_json = :docs_json
+                docs_json = :docs_json,
+                audio_id = :audio_id,
+                audio_expires_ts = :audio_expires_ts
             WHERE id = :id
         """).bindparams(
             id=item.id,
@@ -815,6 +913,8 @@ class Storage:
             output_name=item.output_name,
             input_ts=int(item.input_timestamp or 0),
             output_ts=int(item.output_timestamp or 0),
+            hidden_input=item.hidden_input,
+            hidden_output=item.hidden_output,
             mode=item.mode,
             model=item.model,
             thread_id=item.thread,
@@ -826,12 +926,15 @@ class Storage:
             images_json=pack_item_value(item.images),
             files_json=pack_item_value(item.files),
             attachments_json=pack_item_value(item.attachments),
+            additional_ctx_json=pack_item_value(item.additional_ctx),
             extra=pack_item_value(item.extra),
             input_tokens=int(item.input_tokens or 0),
             output_tokens=int(item.output_tokens or 0),
             total_tokens=int(item.total_tokens or 0),
             is_internal=int(item.internal or 0),
             docs_json=pack_item_value(item.doc_ids),
+            audio_id=item.audio_id,
+            audio_expires_ts=int(item.audio_expires_ts or 0)
         )
         with db.begin() as conn:
             conn.execute(stmt)
@@ -840,12 +943,12 @@ class Storage:
     def get_ctx_count_by_day(
             self,
             year: int,
-            month: int = None,
-            day: int = None,
-            search_string: str = None,
-            filters: dict = None,
+            month: Optional[int] = None,
+            day: Optional[int] = None,
+            search_string: Optional[str] = None,
+            filters: Optional[dict] = None,
             search_content: bool = False,
-    ) -> dict:
+    ) -> Dict[str, int]:
         """
         Return ctx counters by day for given year and month
 
@@ -936,12 +1039,12 @@ class Storage:
     def get_ctx_labels_count_by_day(
             self,
             year: int,
-            month: int = None,
-            day: int = None,
-            search_string: str = None,
-            filters: dict = None,
+            month: Optional[int] = None,
+            day: Optional[int] = None,
+            search_string: Optional[str] = None,
+            filters: Optional[dict] = None,
             search_content: bool = False,
-    ) -> dict:
+    ) -> Dict[str, Dict[int, int]]:
         """
         Return ctx counters by day for given year and month
 
@@ -1065,7 +1168,7 @@ class Storage:
 
                 return result_dict
 
-    def get_groups(self) -> dict:
+    def get_groups(self) -> Dict[int, CtxGroup]:
         """
         Return dict with CtxGroup objects, indexed by ID
 
@@ -1138,6 +1241,18 @@ class Storage:
             conn.execute(text("DELETE FROM sqlite_sequence WHERE name='ctx_group'"))
         return True
 
+    def clear_meta(self, meta_id: int) -> bool:
+        """
+        Delete all items with meta ID
+
+        :param meta_id: meta ID
+        :return: True if cleared
+        """
+        db = self.window.core.db.get_db()
+        with db.begin() as conn:
+            conn.execute(text(f"DELETE FROM ctx_item WHERE meta_id = {meta_id}"))
+        return True
+
     def update_group(self, group: CtxGroup) -> bool:
         """
         Update group
@@ -1196,12 +1311,13 @@ class Storage:
             group.id = result.lastrowid
             return group.id
 
-    def update_meta_group_id(self, meta_id: int, group_id: int = None):
+    def update_meta_group_id(self, meta_id: int, group_id: int = None) -> bool:
         """
         Update meta group ID
 
         :param meta_id: ctx meta ID
         :param group_id: ctx group ID
+        :return: True if updated
         """
         db = self.window.core.db.get_db()
         stmt = text("""
