@@ -6,11 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.31 19:00:00                  #
+# Updated Date: 2025.07.01 01:00:00                  #
 # ================================================== #
 
 from packaging.version import parse as parse_version, Version
 
+from pygpt_net.core.types import MODE_RESEARCH
+
 
 class Patch:
     def __init__(self, window=None):
@@ -328,6 +330,7 @@ class Patch:
                         # langchain
                         is_endpoint = False
                         is_version = False
+                        """
                         for item in model.langchain["env"]:
                             if item["name"] == "AZURE_OPENAI_ENDPOINT":
                                 is_endpoint = True
@@ -355,6 +358,7 @@ class Patch:
                                     "value": "{api_azure_version}",
                                 }
                             )
+                        """
 
                         # llama
                         is_endpoint = False
@@ -390,6 +394,7 @@ class Patch:
                     # Anthropic
                     elif model.id.startswith("claude-"):
                         is_key = False
+                        """
                         for item in model.langchain["env"]:
                             if item["name"] == "ANTHROPIC_API_KEY":
                                 is_key = True
@@ -404,6 +409,7 @@ class Patch:
                                     "value": "{api_key_anthropic}",
                                 }
                             )
+                        """
                         is_key = False
                         for item in model.llama_index["env"]:
                             if item["name"] == "ANTHROPIC_API_KEY":
@@ -422,6 +428,7 @@ class Patch:
                     # Google
                     elif model.id.startswith("gemini-"):
                         is_key = False
+                        """
                         for item in model.langchain["env"]:
                             if item["name"] == "GOOGLE_API_KEY":
                                 is_key = True
@@ -436,6 +443,7 @@ class Patch:
                                     "value": "{api_key_google}",
                                 }
                             )
+                        """
                         is_key = False
                         for item in model.llama_index["env"]:
                             if item["name"] == "GOOGLE_API_KEY":
@@ -481,6 +489,164 @@ class Patch:
                 # add o1, DeepSeek R1, V3
                 updated = True
 
+            # < 2.5.2  <--- update names to models IDs
+            if old < parse_version("2.5.2"):
+                print("Migrating models from < 2.5.2...")
+                for id in data:
+                    model = data[id]
+                    if model.name.startswith("DeepSeek Ollama"):
+                        model.name = model.id
+                updated = True
+
+            # < 2.5.4 <--- add o3-mini, update output tokens in o1, o1-mini, o1-preview
+            if old < parse_version("2.5.4"):
+                print("Migrating models from < 2.5.4...")
+                for id in data:
+                    model = data[id]
+                    if model.id == "o1":
+                        model.tokens = 100000
+                    elif model.id == "o1-mini":
+                        model.tokens = 65536
+                    elif model.id == "o1-preview":
+                        model.tokens = 65536
+                updated = True
+
+            # < 2.5.8 <--- add gpt-4.5-preview and sonar models (Perplexity)
+            if old < parse_version("2.5.8"):
+                print("Migrating models from < 2.5.8...")
+                # add gpt-4.5-preview, sonar, R1
+                updated = True
+
+            # < 2.5.10 <--- add claude-3-7-sonnet-latest
+            if old < parse_version("2.5.10"):
+                print("Migrating models from < 2.5.10...")
+                # add claude-3-7-sonnet-latest
+                updated = True
+
+            # < 2.5.11  <--- update Bielik from v2.2 to v2.3
+            if old < parse_version("2.5.11"):
+                print("Migrating models from < 2.5.11...")
+                # update Bielik from v2.2 to v2.3
+                updated = True
+
+            # < 2.5.12  <--- add gpt-4.1-mini, qwen2.5-coder
+            if old < parse_version("2.5.12"):
+                print("Migrating models from < 2.5.12...")
+                # add gpt-4.1-mini, qwen2.5-coder
+                updated = True
+
+            # < 2.5.15  <--- update deepseek IDs
+            if old < parse_version("2.5.15"):
+                print("Migrating models from < 2.5.15...")
+                replace = [
+                    ["deepseek_ollama_r1_1.5b", "deepseek-r1:1.5b"],
+                    ["deepseek_ollama_r1_7b", "deepseek-r1:7b"],
+                    ["deepseek_ollama_r1_14b", "deepseek-r1:14b"],
+                    ["deepseek_ollama_r1_32b", "deepseek-r1:32b"],
+                    ["deepseek_ollama_r1_70b", "deepseek-r1:70b"],
+                    ["deepseek_ollama_r1_671b", "deepseek-r1:671b"],
+                    ["deepseek_ollama_v3", "deepseek-v3:671b"]
+                ]
+                for m in replace:
+                    name_to_replace = m[0]
+                    new_name = m[1]
+                    if name_to_replace in data:
+                        model = data[name_to_replace]
+                        model.id = new_name
+                        model.name = new_name
+                        data[new_name] = model
+                        del data[name_to_replace]
+                updated = True
+
+            # < 2.5.18 <--- update openai flag
+            if old < parse_version("2.5.18"):
+                print("Migrating models from < 2.5.18...")
+                for id in data:
+                    model = data[id]
+                    if model.is_supported("llama_index"):
+                        if "chat" not in model.mode:
+                            model.mode.append("chat")
+                updated = True
+
+            # < 2.5.19 <--- add Grok models
+            if old < parse_version("2.5.19"):
+                updated = True
+
+            # < 2.5.20 <--- add provider field
+            if old < parse_version("2.5.20"):
+                print("Migrating models from < 2.5.20...")
+                for id in data:
+                    model = data[id]
+
+                    # add global providers
+                    if model.is_ollama():
+                        model.provider = "ollama"
+                    if (model.id.startswith("gpt-")
+                      or model.id.startswith("chatgpt")
+                      or model.id.startswith("o1")
+                      or model.id.startswith("o3")
+                      or model.id.startswith("o4")
+                      or model.id.startswith("o5")
+                      or model.id.startswith("dall-e")):
+                        model.provider = "openai"
+                    if model.id.startswith("claude-"):
+                        model.provider = "anthropic"
+                    if model.id.startswith("gemini-"):
+                        model.provider = "google"
+                    if MODE_RESEARCH in model.mode:
+                        model.provider = "perplexity"
+                    if model.id.startswith("grok-"):
+                        model.provider = "x_ai"
+                    if id.startswith("deepseek_api"):
+                        model.provider = "deepseek_api"
+                    if model.provider is None or model.provider == "":
+                        model.provider = "local_ai"
+
+                    # patch llama_index config
+                    if model.llama_index:
+                        if 'mode' in model.llama_index:
+                            del model.llama_index['mode']
+                        if 'provider' in model.llama_index:
+                            del model.llama_index['provider']
+
+                    # add llama_index mode to o1, o3
+                    if model.id.startswith("o1") or model.id.startswith("o3"):
+                        if "llama_index" not in model.mode:
+                            model.mode.append("llama_index")
+
+                    # del langchain config
+                    if 'langchain' in model.mode:
+                        model.mode.remove("langchain")
+                updated = True
+
+            # < 2.5.23 <--- add Perplexity to rest of modes
+            if old < parse_version("2.5.23"):
+                print("Migrating models from < 2.5.23...")
+                for id in data:
+                    model = data[id]
+                    if model.provider == "perplexity":
+                        if "llama_index" not in model.mode:
+                            model.mode.append("llama_index")
+                        if "agent" not in model.mode:
+                            model.mode.append("agent")
+                        if "agent_llama" not in model.mode:
+                            model.mode.append("agent_llama")
+                        if "expert" not in model.mode:
+                            model.mode.append("expert")
+                        if "chat" not in model.mode:
+                            model.mode.append("chat")
+                updated = True
+
+            # < 2.5.27 <--- add o3, o4 deep research
+            if old < parse_version("2.5.27"):
+                print("Migrating models from < 2.5.27...")
+                updated = True
+
+            # < 2.5.29 <--- add multimodal
+            if old < parse_version("2.5.29"):
+                print("Migrating models from < 2.5.29...")
+                updated = True
+
         # update file
         if updated:
             data = dict(sorted(data.items()))
