@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 22:00:00                  #
+# Updated Date: 2025.06.28 16:00:00                  #
 # ================================================== #
 
 import json
@@ -28,6 +28,7 @@ from pygpt_net.core.types import (
     MODE_LANGCHAIN,
     MODE_LLAMA_INDEX,
     MODE_VISION,
+    MODE_RESEARCH,
 )
 from pygpt_net.provider.core.preset.base import BaseProvider
 from pygpt_net.item.preset import PresetItem
@@ -188,13 +189,14 @@ class JsonFileProvider(BaseProvider):
             MODE_COMPLETION: item.completion,
             MODE_IMAGE: item.img,
             MODE_VISION: item.vision,
-            MODE_LANGCHAIN: item.langchain,
+            # MODE_LANGCHAIN: item.langchain,
             MODE_ASSISTANT: item.assistant,
             MODE_LLAMA_INDEX: item.llama_index,
             MODE_AGENT: item.agent,
             MODE_AGENT_LLAMA: item.agent_llama,
             MODE_EXPERT: item.expert,
             MODE_AUDIO: item.audio,
+            MODE_RESEARCH: item.research,
             'temperature': item.temperature,
             'filename': item.filename,
             'model': item.model,
@@ -222,8 +224,8 @@ class JsonFileProvider(BaseProvider):
             item.img = data[MODE_IMAGE]
         if MODE_VISION in data:
             item.vision = data[MODE_VISION]
-        if MODE_LANGCHAIN in data:
-            item.langchain = data[MODE_LANGCHAIN]
+        # if MODE_LANGCHAIN in data:
+            # item.langchain = data[MODE_LANGCHAIN]
         if MODE_ASSISTANT in data:
             item.assistant = data[MODE_ASSISTANT]
         if MODE_LLAMA_INDEX in data:
@@ -236,6 +238,8 @@ class JsonFileProvider(BaseProvider):
             item.expert = data[MODE_EXPERT]
         if MODE_AUDIO in data:
             item.audio = data[MODE_AUDIO]
+        if MODE_RESEARCH in data:
+            item.research = data[MODE_RESEARCH]
 
         if 'uuid' in data:
             item.uuid = data['uuid']
