@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 22:00:00                  #
+# Updated Date: 2025.06.28 16:00:00                  #
 # ================================================== #
 
 from llama_index.llms.anthropic import Anthropic
@@ -30,6 +30,7 @@ class AnthropicLLM(BaseLLM):
             - api_key: API key for Anthropic API
         """
         self.id = "anthropic"
+        self.name = "Anthropic"
         self.type = [MODE_LLAMA_INDEX]
 
     def llama(
@@ -47,4 +48,6 @@ class AnthropicLLM(BaseLLM):
         :return: LLM provider instance
         """
         args = self.parse_args(model.llama_index)
+        if "model" not in args:
+            args["model"] = model.id
         return Anthropic(**args)
