@@ -6,13 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 22:00:00                  #
+# Updated Date: 2025.06.28 16:00:00                  #
 # ================================================== #
 
 from typing import Optional, List, Dict
 
-from langchain_openai import AzureOpenAI
-from langchain_openai import AzureChatOpenAI
+# from langchain_openai import AzureOpenAI
+# from langchain_openai import AzureChatOpenAI
 
 from llama_index.core.llms.llm import BaseLLM as LlamaBaseLLM
 from llama_index.core.base.embeddings.base import BaseEmbedding
@@ -20,7 +20,6 @@ from llama_index.llms.azure_openai import AzureOpenAI as LlamaAzureOpenAI
 from llama_index.embeddings.azure_openai import AzureOpenAIEmbedding
 
 from pygpt_net.core.types import (
-    MODE_LANGCHAIN,
     MODE_LLAMA_INDEX,
 )
 from pygpt_net.provider.llms.base import BaseLLM
@@ -39,7 +38,8 @@ class AzureOpenAILLM(BaseLLM):
             - api_key: API key for Azure OpenAI API
         """
         self.id = "azure_openai"
-        self.type = [MODE_LANGCHAIN, MODE_LLAMA_INDEX, "embeddings"]
+        self.name = "Azure OpenAI"
+        self.type = [MODE_LLAMA_INDEX, "embeddings"]
 
     def completion(
             self,
@@ -54,9 +54,11 @@ class AzureOpenAILLM(BaseLLM):
         :param model: model instance
         :param stream: stream mode
         :return: LLM provider instance
-        """
+
         args = self.parse_args(model.langchain)
         return AzureOpenAI(**args)
+        """
+        pass
 
     def chat(
             self,
@@ -71,9 +73,11 @@ class AzureOpenAILLM(BaseLLM):
         :param model: model instance
         :param stream: stream mode
         :return: LLM provider instance
-        """
+
         args = self.parse_args(model.langchain)
         return AzureChatOpenAI(**args)
+        """
+        pass
 
     def llama(
             self,
