@@ -6,21 +6,21 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.31 19:00:00                  #
+# Updated Date: 2025.06.28 16:00:00                  #
 # ================================================== #
 
 import os
 from typing import Optional, List, Dict
 
-from langchain_community.chat_models import ChatOllama
+# from langchain_community.chat_models import ChatOllama
+
+from .ollama_custom import Ollama
 
-from llama_index.llms.ollama import Ollama
 from llama_index.core.llms.llm import BaseLLM as LlamaBaseLLM
 from llama_index.core.base.embeddings.base import BaseEmbedding
 from llama_index.embeddings.ollama import OllamaEmbedding
 
 from pygpt_net.core.types import (
-    MODE_LANGCHAIN,
     MODE_LLAMA_INDEX,
 )
 from pygpt_net.provider.llms.base import BaseLLM
@@ -32,7 +32,8 @@ class OllamaLLM(BaseLLM):
     def __init__(self, *args, **kwargs):
         super(OllamaLLM, self).__init__(*args, **kwargs)
         self.id = "ollama"
-        self.type = [MODE_LANGCHAIN, MODE_LLAMA_INDEX, "embeddings"]
+        self.name = "Ollama"
+        self.type = [MODE_LLAMA_INDEX, "embeddings"]
 
     def completion(
             self,
@@ -48,7 +49,7 @@ class OllamaLLM(BaseLLM):
         :param stream: stream mode
         :return: LLM provider instance
         """
-        return None
+        pass
 
     def chat(
             self,
@@ -63,9 +64,13 @@ class OllamaLLM(BaseLLM):
         :param model: model instance
         :param stream: stream mode
         :return: LLM provider instance
-        """
+
         args = self.parse_args(model.langchain)
+        if "model" not in args:
+            args["model"] = model.id
         return ChatOllama(**args)
+        """
+        pass
 
     def llama(
             self,
@@ -85,6 +90,11 @@ class OllamaLLM(BaseLLM):
         args = self.parse_args(model.llama_index)
         if "request_timeout" not in args:
             args["request_timeout"] = 120
+        if 'OLLAMA_API_BASE' in os.environ:
+            if "base_url" not in args:
+                args["base_url"] = os.environ['OLLAMA_API_BASE']
+        if "model" not in args:
+            args["model"] = model.id
         return Ollama(**args)
 
     def get_embeddings_model(
@@ -104,6 +114,9 @@ class OllamaLLM(BaseLLM):
             args = self.parse_args({
                 "args": config,
             })
+        if 'OLLAMA_API_BASE' in os.environ:
+            if "base_url" not in args:
+                args["base_url"] = os.environ['OLLAMA_API_BASE']
         return OllamaEmbedding(**args)
 
     def init_embeddings(
